[llvm] r263585 - Also handle the new Rust pers fn to isCatchAll()

Bjorn Steinbrink via llvm-commits llvm-commits at lists.llvm.org
Tue Mar 15 13:57:07 PDT 2016


Author: bsteinbr
Date: Tue Mar 15 15:57:07 2016
New Revision: 263585

URL: http://llvm.org/viewvc/llvm-project?rev=263585&view=rev
Log:
Also handle the new Rust pers fn to isCatchAll()

Modified:
    llvm/trunk/lib/Transforms/InstCombine/InstructionCombining.cpp

Modified: llvm/trunk/lib/Transforms/InstCombine/InstructionCombining.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Transforms/InstCombine/InstructionCombining.cpp?rev=263585&r1=263584&r2=263585&view=diff
==============================================================================
--- llvm/trunk/lib/Transforms/InstCombine/InstructionCombining.cpp (original)
+++ llvm/trunk/lib/Transforms/InstCombine/InstructionCombining.cpp Tue Mar 15 15:57:07 2016
@@ -2370,8 +2370,9 @@ Instruction *InstCombiner::visitExtractV
 static bool isCatchAll(EHPersonality Personality, Constant *TypeInfo) {
   switch (Personality) {
   case EHPersonality::GNU_C:
-    // The GCC C EH personality only exists to support cleanups, so it's not
-    // clear what the semantics of catch clauses are.
+  case EHPersonality::Rust:
+    // The GCC C EH and Rust personality only exists to support cleanups, so
+    // it's not clear what the semantics of catch clauses are.
     return false;
   case EHPersonality::Unknown:
     return false;




More information about the llvm-commits mailing list